__all__ = (
    "GJ_FIX",
    "GJ_FEAT",
    "GJ_DOCS",
    "GJ_STYLE",
    "GJ_REFACTOR",
    "GJ_PERF",
    "GJ_TEST",
    "GJ_BUILD",
    "GJ_CI",
    "GJ_REVERT",
    "GJ_DUMP",
    "GJ_HOTFIX",
    "GJ_DEPLOY",
    "GJ_UI",
    "GJ_INIT",
    "GJ_SECURITY",
    "GJ_SECRET",
    "GJ_BUMP",
    "GJ_FIX_LINT",
    "GJ_WIP",
    "GJ_DEP_DROP",
    "GJ_DEP_BUMP",
    "GJ_PIN",
    "GJ_ANALYTICS",
    "GJ_DEP_ADD",
    "GJ_DEP_RM",
    "GJ_CONFIG",
    "GJ_SCRIPT",
    "GJ_LANG",
    "GJ_TYPO",
    "GJ_POOP",
    "GJ_MERGE",
    "GJ_PACKAGE",
    "GJ_EXTERNAL",
    "GJ_RESOURCE",
    "GJ_LICENSE",
    "GJ_BOOM",
    "GJ_ASSET",
    "GJ_ACCESSIBILITY",
    "GJ_SOURCE_DOCS",
    "GJ_BEER",
    "GJ_TEXT",
    "GJ_DB",
    "GJ_LOGS_ADD",
    "GJ_LOGS_RM",
    "GJ_PEOPLE",
    "GJ_UX",
    "GJ_ARCH",
    "GJ_DESIGN",
    "GJ_MOCK",
    "GJ_EGG",
    "GJ_IGNORE",
    "GJ_SNAP",
    "GJ_EXPERIMENT",
    "GJ_SEO",
    "GJ_TYPES",
    "GJ_SEED",
    "GJ_FLAG",
    "GJ_CATCH",
    "GJ_ANIMATION",
    "GJ_DEPRECATION",
    "GJ_AUTH",
    "GJ_FIX_SIMPLE",
    "GJ_EXPLORATION",
    "GJ_DEAD",
    "GJ_TEST_FAIL",
    "GJ_LOGIC",
    "GJ_HEALTH",
    "GJ_INFRA",
    "GJ_DEVXP",
    "GJ_MONEY",
    "GJ_THREADING",
    "GJ_VALIDATION",
    "GJ_CHORE",
    "GJ_SQUASH",
    "GJ_FIXUP",
)

GJ_FIX = "🐛"
GJ_FEAT = "✨"
GJ_DOCS = "📝"
GJ_STYLE = "🎨"
GJ_REFACTOR = "♻️ "
GJ_PERF = "⚡️"
GJ_TEST = "✅"
GJ_BUILD = "👷"
GJ_CI = "💚"
GJ_REVERT = "⏪️"
GJ_DUMP = "🔥"
GJ_HOTFIX = "🚑️"
GJ_DEPLOY = "🚀"
GJ_UI = "💄"
GJ_INIT = "🎉"
GJ_SECURITY = "🔒️"
GJ_SECRET = "🔐"
GJ_BUMP = "🔖"
GJ_FIX_LINT = "🚨"
GJ_WIP = "🚧"
GJ_DEP_DROP = "⬇️ "
GJ_DEP_BUMP = "⬆️ "
GJ_PIN = "📌"
GJ_ANALYTICS = "📈"
GJ_DEP_ADD = "➕"
GJ_DEP_RM = "➖"
GJ_CONFIG = "🔧"
GJ_SCRIPT = "🔨"
GJ_LANG = "🌐"
GJ_TYPO = "✏️ "
GJ_POOP = "💩"
GJ_MERGE = "🔀"
GJ_PACKAGE = "📦️"
GJ_EXTERNAL = "👽️"
GJ_RESOURCE = "🚚"
GJ_LICENSE = "📄"
GJ_BOOM = "💥"
GJ_ASSET = "🍱"
GJ_ACCESSIBILITY = "♿️"
GJ_SOURCE_DOCS = "💡"
GJ_BEER = "🍻"
GJ_TEXT = "💬"
GJ_DB = "🗃️"
GJ_LOGS_ADD = "🔊"
GJ_LOGS_RM = "🔇"
GJ_PEOPLE = "👥"
GJ_UX = "🚸"
GJ_ARCH = "🏗️"
GJ_DESIGN = "📱"
GJ_MOCK = "🤡"
GJ_EGG = "🥚"
GJ_IGNORE = "🙈"
GJ_SNAP = "📸"
GJ_EXPERIMENT = "⚗️ "
GJ_SEO = "🔍️"
GJ_TYPES = "🏷️"
GJ_SEED = "🌱"
GJ_FLAG = "🚩"
GJ_CATCH = "🥅"
GJ_ANIMATION = "💫"
GJ_DEPRECATION = "🗑️"
GJ_AUTH = "🛂"
GJ_FIX_SIMPLE = "🩹"
GJ_EXPLORATION = "🧐"
GJ_DEAD = "⚰️ "
GJ_TEST_FAIL = "🧪"
GJ_LOGIC = "👔"
GJ_HEALTH = "🩺"
GJ_INFRA = "🧱"
GJ_DEVXP = "🧑‍💻"
GJ_MONEY = "💸"
GJ_THREADING = "🧵"
GJ_VALIDATION = "🦺"
GJ_CHORE = "🧹"
GJ_SQUASH = "👇"
GJ_FIXUP = "🫥"
